function [coordinate, faces, faceCentres, pressure, velocity] = OF_ReadSampleFile_Surfaces()
% This function loads OpenFOAM constant and inperpolated planes extracted
% using the 'sample' utility and converts the plane/planes into a
% triangular mesh format readily recognised by Matlab
%
% Usage: 
% - The user must change the current directory to the time directory of
% interest (within the 'object' i.e. interpolatedPlane of the name given   to the surface itself)
% - ConstantPlane data should be plot using trisuf(faces,x,y,z,pressure/   % velocity.component).
% - Interpolated planes should be plot using trisurf (faces,x,y,z,pressure/% velocity.component, 'facecolor','interp')
% - NOTE: for best results use triangleCut and cellPoint interpolation
% (cellPointFace takes longer to sample and no obvious improvement in the
% quality of the final figure was observed)
%
% Output:
% - coordinate: structure array containing x, y and z coordinates
% - faces: array of size mx3 containing the indices to the vertices 
%   of every triangle. Corresponds to the tri matrix need for the trisurf
%   function.
% - pressure: scalar values for at each coordinate. Used in colormap!
% - velocity: structure array containing velocity component in x, y and z.


% Load faces
 fid = fopen('faces','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('Reading faces')
  
 OF_faces = fscanf(fid,'%d(%d %d %d)', [4 inf])';
 
 fclose(fid);
 
 % Removing first column (number of verticies 
 % e.g. 3 for triangulated surface)
 faces(:,1) = OF_faces(:,2);
 faces(:,2) = OF_faces(:,3);
 faces(:,3) = OF_faces(:,4);
 
 % Converting to Matlab/Octave format (e.g. index + 1)
 faces = faces + 1;
 
 clear OF_faces;
 
 % Load face centres
 fid = fopen('faceCentres','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('Reading face centres')
  
 OF_face_centres = fscanf(fid,'(%f %f %f)\n', [3 inf])';
 
 fclose(fid);
 
 %Removing first column (number of verticies 
 % e.g. 3 for triangulated surface)
 faceCentres.x = OF_face_centres(:,1);
 faceCentres.y = OF_face_centres(:,2);
 faceCentres.z = OF_face_centres(:,3);
 
 
 clear OF_face_centres;
 
% Load points
 fid = fopen('points','rt');
  
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 disp('Reading coordinate points')
 points = fscanf(fid,'(%f %f %f)\n', [3 inf])';
 
 fclose(fid);
 
coordinate.x = points(:,1);
coordinate.y = points(:,2);
coordinate.z = points(:,3);

clear points;

%%%%%%%%%%%%%%%%%%%%%%%%%% Load scalars %%%%%%%%%%%%%%%%%%%%%%%%%%

cd scalarField

 fid = fopen('p','rt');

  disp('Reading scalar')
 
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 pressure = fscanf(fid,'%e\n', [1 inf])';
 
 fclose(fid);
 
 cd ..
 
%%%%%%%%%%%%%%%%%%%%%%%%%% Load velocity %%%%%%%%%%%%%%%%%%%%%%%%%%

cd vectorField

 fid = fopen('U','rt');

  disp('Reading velocity')
 
  fgetl(fid);
  fgetl(fid);
  fgetl(fid);
 
 OF_velocity = fscanf(fid,'(%f %f %f)\n', [3 inf])';
 
 fclose(fid);
 
 velocity.x = OF_velocity(:,1);
 velocity.y = OF_velocity(:,2);
 velocity.z = OF_velocity(:,3);
 
 cd ..
 
 disp('Load completed successully')
