function [caseTime, time] = OF_Store_Sets()
% Stores set data extracted with the 'sample utility'. This function reads and
% stores both lines and points. The data is saved using a structure array of
% the form:
%
%	caseTime.sets.<fields>
%
% Where fields can be either <sample> or <name>. This is where the data and 
% the file name are stored respectively. Notice that <sample> will contain the
% data stored in an nxm array where n is the number of points sampled by point 
% or the line and m represents the number of characteristics sampled i.e x, y,
% z, vx, vy, vz or p. Additionally, time information has been saved as a 
% separate variable named 'time'. Finally, the data is saved within the 
% 'OFMatData' directory in MatLab format under 'sets.mat'.


originalDir = pwd;

cd sets;

directories = dir;
[r c] = size(directories);

% Covert directory names into numbers for numerical/ascending sorting
for timeDir = 3:r;
numberDir(timeDir) = str2num(directories(timeDir).name);
end

% Sorting directories in ascending order (numerically)
[SortedDirectories, orderedIndex] = sort(numberDir);
time = SortedDirectories;

for timeDir = 3:r

% Entering time directory using ordered indices
cd (directories(orderedIndex(timeDir)).name)

% Calling OF_ReadSampleFileSet to read all files within directory

[setData] = OF_ReadSampleFile_Sets();

% Saving data/set in structure array
caseTime(timeDir-2).sets = setData; % substract 2 to ignor directories . & ..
cd .. 
end

disp('Files in sets directory read and stored successfully')

% Return to root directory
cd (originalDir);

%%%%% Save data in matlab format ready for plotting %%%%%

% Check existance of 'OFMatData' directory and saves probes data %

OFMatDir = strcat((originalDir),'/OFMatData');
if exist((OFMatDir)) == 7
disp('OFMatData directory exists: Entering to save data')
cd (OFMatDir);
save -mat sets.mat caseTime time
elseif exist((OFMatDir)) == 0
disp('OFMatData directory does not exists: Creating directory to save data')
mkdir (OFMatDir);
cd (OFMatDir);
save -mat sets.mat caseTime time
else
error('This case is not set up correctly for use with this library')
end



% Return to root directory
cd (originalDir);

